@@ -25,10 +25,10 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
+#include <libgd/gd-main-toolbar.h>
 
 #include "logview-window.h"
 
-#include "gd-main-toolbar.h"
 #include "logview-loglist.h"
 #include "logview-findbar.h"
 #include "logview-prefs.h"
